# SpeciPy
SpeciPy simplifies the implementation of the Specification pattern in Python, enabling easy creation and evaluation of flexible rules and criteria.

[![Build status](https://github.com/danieljoris/specipy/actions/workflows/ci.yml/badge.svg?branch=main)](https://github.com/danieljoris/specipy/actions/workflows/ci.yml) [![Python Versions](https://img.shields.io/pypi/pyversions/specipy.svg)](https://pypi.org/project/specipy/) [![Package Version](https://badge.fury.io/py/specipy.svg)](https://pypi.org/project/specipy/) [![Coverage Status](https://codecov.io/gh/danieljoris/specipy/branch/main/graph/badge.svg?token=C70HMVKXDK)](https://codecov.io/gh/danieljoris/specipy) [![Code Style: Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black) [![License](https://img.shields.io/github/license/danieljoris/specipy)](https://github.com/danieljoris/specipy/blob/main/LICENSE)

---

## 📋 Table of Contents

- [📥 Installation](#-installation)
- [🚀 Usage](#-usage)
- [🤝 Contributing](#-contributing)
- [📜 License](#-license)
- [📧 Contact](#-contact)

---

## 📥 Installation

To install Interpy with `pip`, you can use the following command:

```bash
pip install specipy
```
If you are using `poetry` you can use the command:

```bash
poetry add specipy
```

---

## 🚀 Usage

Here is a basic example of how to use Specipy:



---


## 🤝 Contributing
If you would like to contribute to Specipy, please follow these steps:

1. Fork the repository
    `git clone git@github.com:danieljoris/specipy.git`
2. Create a branch for your feature 
    `git checkout -b feature/your-feature`
3. Commit your changes 
    `git commit -m 'Add your feature`
4. Push to the branch 
    `git push origin feature/your-feature`
5. Open a Pull Request

---

## 📜 License
This project is licensed under the MIT License. See the LICENSE file for more details.

---

## 📧 Contact

Feel free to adjust and add more features as needed. If you need anything more specific or additional adjustments, let me know!
